@@ -1,11 +1,7 @@
 """Script containing util functions for 3aransia"""
 
 import re
-import csv
 
-from aaransia.defaults import BASE_DIR, DATA_DIR, ALPHABET_FILE
-
-# Remove noise from arabic text
 def de_noise(text):
     """Returns a de-noised arabic text
 
@@ -25,7 +21,6 @@ def de_noise(text):
     text = re.sub(noise, '', text)
     return text
 
-# Normalize arabic
 def normalize_arabic(text):
     """Returns a normalized arabic text
 
@@ -37,13 +32,3 @@ def normalize_arabic(text):
     text = re.sub("ؤ", "ء", text)
     text = re.sub("ئ", "ء", text)
     return text
-
-# Construct alphabet dictionary
-def construct_alphabet():
-    """Returns the constructed alphabet from the csv file in data
-    """
-    with open(BASE_DIR + DATA_DIR + ALPHABET_FILE) as file_handler:
-        dict_reader, alphabet = csv.DictReader(file_handler, delimiter=','), list()
-        for row in dict_reader:
-            alphabet.append(row)
-        return alphabet
